@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 """
 Settings and global variables used in the reading and plotting procedures
 """
@@ -7,12 +6,14 @@ Settings and global variables used in the reading and plotting procedures
 import warnings
 
 import cartopy.crs as ccrs
+import matplotlib.colors as cl
 import matplotlib.pyplot as plt
 
 # PLOT DEFAULT SETTINGS
 # =====================================================
 matplotlib_ppi = 72  # Don't change this, it's a matplotlib convention.
-index_names = ['lat', 'lon', 'gpi']  # Names used for 'latitude' and 'longitude' coordinate.
+index_names = ['lat', 'lon',
+               'gpi']  # Names used for 'latitude' and 'longitude' coordinate.
 time_name = 'time'  # not used at the moment, dropped on load
 period_name = 'period'  # not used at the moment, dropped on load
 
@@ -22,14 +23,18 @@ title_pad = 12.0  # Padding below the title in points. default padding is matplo
 data_crs = ccrs.PlateCarree()  # Default map projection. use one of
 
 # === map plot defaults ===
-scattered_datasets = ['ISMN']  # dataset names which require scatterplots (values is scattered in lat/lon)
+scattered_datasets = [
+    'ISMN'
+]  # dataset names which require scatterplots (values is scattered in lat/lon)
 map_figsize = [11.32, 6.10]  # size of the output figure in inches.
 naturalearth_resolution = '110m'  # One of '10m', '50m' and '110m'. Finer resolution slows down plotting. see https://www.naturalearthdata.com/
-crs = ccrs.PlateCarree()  # projection. Must be a class from cartopy.crs. Note, that plotting labels does not work for most projections.
+crs = ccrs.PlateCarree(
+)  # projection. Must be a class from cartopy.crs. Note, that plotting labels does not work for most projections.
 markersize = 4  # diameter of Marker in points.
 map_pad = 0.15  # padding relative to map height.
-grid_intervals = [2, 5, 10,
-                  30]  # grid spacing in degree to choose from (plotter will try to make 5 gridlines in the smaller dimension)
+grid_intervals = [
+    2, 5, 10, 30
+]  # grid spacing in degree to choose from (plotter will try to make 5 gridlines in the smaller dimension)
 max_title_len = 8 * map_figsize[
     0]  # maximum length of plot title in chars. if longer, it will be broken in multiple lines.
 
@@ -55,6 +60,28 @@ out_metadata_plots = {
     "lc": ["lc_2010"],
     "climate": ["climate_KG"],
     "soil": ["instrument_depth", "soil_type"],
+    "frm_class": ['frm_class'],
+}
+
+# === calculation errors (pytesmo) === #TODO: import from pytesmo
+status = {
+    -1: 'Other error',
+    0: 'Success',
+    1: 'Not enough data',
+    2: 'Metric calculation failed',
+    3: 'Temporal matching failed',
+    4: 'No overlap for temporal match',
+    5: 'Scaling failed',
+    6: 'Unexpected validation error',
+    7: 'Missing GPI data',
+    8: 'Data reading failed'
+}
+
+# helper dict to replace some error codes and have merged categories
+# (e.g.: No overlap for temporal match -> Temporal matching failed)
+status_replace = {
+    4: 3,
+    7: 1,
 }
 
 # === colormaps used for plotting metrics ===
@@ -62,12 +89,34 @@ out_metadata_plots = {
 # Any colormap name can be used, that works with matplotlib.pyplot.cm.get_cmap('colormap')
 # more on colormaps: https://matplotlib.org/users/colormaps.html | https://morphocode.com/the-use-of-color-in-maps/
 
+
+def get_status_colors():
+    # function to get custom cmap for calculation errors
+    # limited to 14 different error entries to produce distinct colors
+    cmap = plt.cm.get_cmap('Set3', len(status) - 2)
+    colors = [cmap(i) for i in range(cmap.N)]
+    colors.insert(0, (0, 0.66666667, 0.89019608, 1.0))
+    colors.insert(0, (0.45882353, 0.08235294, 0.11764706, 1.0))
+    cmap = cl.ListedColormap(colors=colors)
+    return cmap
+
+
 _cclasses = {
-    'div_better': plt.cm.get_cmap('RdYlBu'),  # diverging: 1 good, 0 special, -1 bad (pearson's R, spearman's rho')
-    'div_worse': plt.cm.get_cmap('RdYlBu_r'),  # diverging: 1 bad, 0 special, -1 good (difference of bias)
-    'div_neutr': plt.cm.get_cmap('RdYlGn'),  # diverging: zero good, +/- neutral: (bias)
-    'seq_worse': plt.cm.get_cmap('YlGn_r'),  # sequential: increasing value bad (p_R, p_rho, rmsd, ubRMSD, RSS)
-    'seq_better': plt.cm.get_cmap('YlGn'),  # sequential: increasing value good (n_obs, STDerr)
+    'div_better': plt.cm.get_cmap(
+        'RdYlBu'
+    ),  # diverging: 1 good, 0 special, -1 bad (pearson's R, spearman's rho')
+    'div_worse': plt.cm.get_cmap(
+        'RdYlBu_r'
+    ),  # diverging: 1 bad, 0 special, -1 good (difference of bias)
+    'div_neutr':
+    plt.cm.get_cmap('RdYlGn'),  # diverging: zero good, +/- neutral: (bias)
+    'seq_worse': plt.cm.get_cmap(
+        'YlGn_r'
+    ),  # sequential: increasing value bad (p_R, p_rho, rmsd, ubRMSD, RSS)
+    'seq_better': plt.cm.get_cmap(
+        'YlGn'),  # sequential: increasing value good (n_obs, STDerr)
+    'qua_neutr':
+    get_status_colors(),  # qualitative category with 2 forced colors
 }
 
 _colormaps = {  # from /qa4sm/validator/validation/graphics.py
@@ -89,6 +138,7 @@ _colormaps = {  # from /qa4sm/validator/validation/graphics.py
     'snr': _cclasses['div_better'],
     'err_std': _cclasses['seq_worse'],
     'beta': _cclasses['div_neutr'],
+    'status': _cclasses['qua_neutr'],
 }
 
 # Colorbars for difference plots
@@ -117,11 +167,11 @@ _diff_colormaps = {  # from /qa4sm/validator/validation/graphics.py
 # 0=common metrics, 2=paired metrics (2 datasets), 3=triple metrics (TC, 3 datasets)
 metric_groups = {
     0: ['n_obs'],
-    2: ['R', 'p_R', 'rho', 'p_rho', 'RMSD', 'BIAS',
-        'urmsd', 'mse', 'mse_corr', 'mse_bias', 'mse_var',
-        'RSS', 'tau', 'p_tau'
-        ],
-    3: ['snr', 'err_std', 'beta']
+    2: [
+        'R', 'p_R', 'rho', 'p_rho', 'RMSD', 'BIAS', 'urmsd', 'mse', 'mse_corr',
+        'mse_bias', 'mse_var', 'RSS', 'tau', 'p_tau', 'status'
+    ],
+    3: ['snr', 'err_std', 'beta', 'status']
 }
 
 # === variable template ===
@@ -138,8 +188,10 @@ var_name_CI = {
 }
 # how two datasets are separated, ids must be marked as numbers with :d!
 var_name_ds_sep = {
-    0: None, 2: "{ref_id:d}-{ref_ds}_and_{sat_id0:d}-{sat_ds0}",
-    3: "{ref_id:d}-{ref_ds}_and_{sat_id0:d}-{sat_ds0}_and_{sat_id1:d}-{sat_ds1}"
+    0: None,
+    2: "{ref_id:d}-{ref_ds}_and_{sat_id0:d}-{sat_ds0}",
+    3:
+    "{ref_id:d}-{ref_ds}_and_{sat_id0:d}-{sat_ds0}_and_{sat_id1:d}-{sat_ds1}"
 }
 
 # === metadata templates ===
@@ -152,7 +204,8 @@ _val_dc_variable_pretty_name = 'val_dc_variable_pretty_name{:d}'  # attribute co
 
 # format should have (metric, ds, ref, other ds)
 _variable_pretty_name = {
-    0: "{}", 2: "{}\nof {}\nwith {} as reference",
+    0: "{}",
+    2: "{}\nof {}\nwith {} as reference",
     3: "{} of {} \n against {}, {}"
 }
 
@@ -180,6 +233,7 @@ _metric_value_ranges = {  # from /qa4sm/validator/validation/graphics.py
     'snr': [None, None],
     'err_std': [None, None],
     'beta': [None, None],
+    'status': [-1, len(status)-2],
 }
 # mask values out of range
 _metric_mask_range = {
@@ -210,6 +264,7 @@ _metric_description = {  # from /qa4sm/validator/validation/graphics.py
     'snr': ' in dB',
     'err_std': ' in {}',
     'beta': ' in {}',
+    'status': '',
 }
 
 
@@ -234,6 +289,8 @@ def get_metric_units(dataset, raise_error=False):
         'CGLS_CSAR_SSM1km': '% saturation',
         'CGLS_SCATSAR_SWI1km': '% saturation',
         'SMOS_L3': 'm³/m³',
+        'SMOS_L2': 'm³/m³',
+        'SMAP_L2': 'm³/m³',
     }
 
     try:
@@ -242,8 +299,7 @@ def get_metric_units(dataset, raise_error=False):
     except KeyError:
         if raise_error:
             raise KeyError(
-                f"The dataset {dataset} has not been specified in {__name__}"
-            )
+                f"The dataset {dataset} has not been specified in {__name__}")
 
         else:
             warnings.warn(
@@ -274,6 +330,7 @@ _metric_name = {  # from /qa4sm/validator/validation/globals.py
     'snr': 'Signal-to-noise ratio',
     'err_std': 'Error standard deviation',
     'beta': 'TC scaling coefficient',
+    'status': 'Validation errors'
 }
 
 # BACKUPS
@@ -301,6 +358,8 @@ _dataset_pretty_names = {  # from qa4sm\validator\fixtures\datasets.json
     'CGLS_CSAR_SSM1km': 'CGLS S1 SSM',
     'CGLS_SCATSAR_SWI1km': 'CGLS SCATSAR SWI',
     'SMOS_L3': 'SMOS L3',
+    'SMOS_L2': 'SMOS L2',
+    'SMAP_L2': 'SMAP L3',
 }
 
 # available backups
@@ -323,6 +382,7 @@ _dataset_version_pretty_names = {  # from qa4sm\validator\fixtures\versions.json
     "ISMN_V20190222_GLOBAL": "20190222 global",
     "ISMN_V20191211_GLOBAL": "20191211 global",
     "ISMN_V20210131": "20210131 global",
+    "ISMN_V20230110": "20230110 global",
     "GLDAS_NOAH025_3H_2_1": "NOAH025 3H.2.1",
     "GLDAS_TEST": "TEST",
     "ESA_CCI_SM_C_V04_4": "v04.4",
@@ -341,6 +401,8 @@ _dataset_version_pretty_names = {  # from qa4sm\validator\fixtures\versions.json
     "CGLS_SCATSAR_SWI1km_V1_0": "v1_0",
     "SMOSL3_v339_ASC": "version 339 Ascending",
     "SMOSL3_v339_DESC": "version 339 Descending",
+    "SMAPL2_V8": 'V8',
+    "SMOSL2_700": 'v700',
 }
 
 # fallback for dataset val_dc_variable in case they are not in the metadata
@@ -358,6 +420,7 @@ _dataset_variable_names = {  # from qa4sm\validator\fixtures\versions.json
     "ISMN_V20190222_GLOBAL": "soil moisture",
     "ISMN_V20191211_GLOBAL": "soil moisture",
     "ISMN_V20210131": "soil moisture",
+    "ISMN_V20230110": "soil moisture",
     "GLDAS_NOAH025_3H_2_1": "soil moisture depth unknown",
     "GLDAS_TEST": "soil moisture depth unknown",
     "ESA_CCI_SM_C_V04_4": "soil moisture",
@@ -375,7 +438,9 @@ _dataset_variable_names = {  # from qa4sm\validator\fixtures\versions.json
     "CGLS_CSAR_SSM1km_V1_1": "soil moisture",
     "CGLS_SCATSAR_SWI1km_V1_0": "SWI",
     "SMOSL3_v339_ASC": "soil moisture",
-    "SMOSL3_v339_DESC": "soil moisture"
+    "SMOSL3_v339_DESC": "soil moisture",
+    "SMOSL2_sm": 'soil moisture',
+    "SMAPL2_soil_moisture": 'soil moisture',
 }
 
 
@@ -405,6 +470,8 @@ def get_resolution_info(dataset, raise_error=False):
         'CGLS_CSAR_SSM1km': 1,
         'CGLS_SCATSAR_SWI1km': 1,
         'SMOS_L3': 25,
+        'SMOS_L2': 15,
+        'SMAP_L2': 35,
     }
 
     # fallback for resolution unit information
@@ -426,6 +493,8 @@ def get_resolution_info(dataset, raise_error=False):
         'CGLS_CSAR_SSM1km': 'km',
         'CGLS_SCATSAR_SWI1km': 'km',
         'SMOS_L3': 'km',
+        'SMOS_L2': 'km',
+        'SMAP_L2': 'km',
     }
 
     try:
@@ -437,8 +506,7 @@ def get_resolution_info(dataset, raise_error=False):
     except KeyError:
         if raise_error:
             raise KeyError(
-                f"The dataset {dataset} has not been specified in {__name__}"
-            )
+                f"The dataset {dataset} has not been specified in {__name__}")
 
         else:
             warnings.warn(
@@ -496,6 +564,7 @@ lc_classes = {
 
 climate_classes = {
     "unknown": "Not provided",
+    "masked": "Not provided",
     "Af": "Tropical",
     "Am": "Tropical",
     "As": "Tropical",
@@ -535,16 +604,20 @@ climate_classes = {
 
 metadata = {
     "clay_fraction": ("clay fraction", None, "continuous", "[% weight]"),
-    "climate_KG": ("Koeppen-Geiger climate class", climate_classes, "classes", None),
+    "climate_KG":
+    ("Koeppen-Geiger climate class", climate_classes, "classes", None),
     "climate_insitu": ("climate in-situ", climate_classes, "classes", None),
     "elevation": ("elevation", None, "continuous", "[m]"),
-    "instrument": ("instrument type", None, "discrete", None),  # todo: improve labels (too packed)
+    "instrument": ("instrument type", None, "discrete",
+                   None),  # todo: improve labels (too packed)
     "lc_2000": ("land cover class (2000)", lc_classes, "classes", None),
     "lc_2005": ("land cover class (2005)", lc_classes, "classes", None),
     "lc_2010": ("land cover class (2010)", lc_classes, "classes", None),
-    "lc_insitu": ("land cover class in-situ", lc_classes, "classes", None),  # todo: handle custom names
+    "lc_insitu": ("land cover class in-situ", lc_classes, "classes",
+                  None),  # todo: handle custom names
     "network": ("network", None, "discrete", None),
-    "organic_carbon": ("concentration of organic carbon", None, "continuous", "[% weight]"),
+    "organic_carbon":
+    ("concentration of organic carbon", None, "continuous", "[% weight]"),
     "sand_fraction": ("sand fraction", None, "continuous", "[% weight]"),
     "saturation": ("saturation", None, "continuous", "[m³/m³]"),
     "silt_fraction": ("silt fraction", None, "continuous", "[% weight]"),
@@ -554,6 +627,8 @@ metadata = {
     # --- generated during the image initialization:
     "soil_type": ("soil granulometry", None, "discrete", None),
     "instrument_depth": ("instrument depth", None, "continuous", "[m]"),
+    # --- FRM4SM QI, not always present
+    "frm_class": ("FRM Classification", None, "discrete", None)
 }
 
 soil_types = ["clay_fraction", "silt_fraction", "sand_fraction"]
