@@ -23,11 +23,14 @@ class MixinVarmeta:
             name = template.format(self.metric)
 
         elif self.g == 2:
-            name = template.format(self.Metric.pretty_name, self.metric_ds[1]['pretty_title'],
-                               self.ref_ds[1]['pretty_title'])
+            name = template.format(self.Metric.pretty_name,
+                                   self.metric_ds[1]['pretty_title'],
+                                   self.ref_ds[1]['pretty_title'])
         elif self.g == 3:
-            name = template.format(self.Metric.pretty_name, self.metric_ds[1]['pretty_title'],
-                               self.ref_ds[1]['pretty_title'], self.other_ds[1]['pretty_title'])
+            name = template.format(self.Metric.pretty_name,
+                                   self.metric_ds[1]['pretty_title'],
+                                   self.ref_ds[1]['pretty_title'],
+                                   self.other_ds[1]['pretty_title'])
 
         return name
 
@@ -61,8 +64,13 @@ class MixinVarmeta:
             ref_ds = self.Datasets.dataset_metadata(self.parts['ref_id'])
             mds = self.Datasets.dataset_metadata(self.parts['sat_id0'])
             dss = None
+
+            # if metric is status and globals.metric_groups is 3, add third dataset
+            if self.g == 3 and self.metric == 'status':
+                dss = self.Datasets.dataset_metadata(self.parts['sat_id1'])
+
             # if metric is TC, add third dataset
-            if self.g == 3:
+            elif self.g == 3:
                 mds = self.Datasets.dataset_metadata(self.parts['mds_id'])
                 dss = self.Datasets.dataset_metadata(self.parts['sat_id1'])
                 if dss == mds:
@@ -107,7 +115,8 @@ class QA4SMDatasets():
             val_ref = self.meta[globals._ref_ds_attr]
             ref_dc = parse(globals._ds_short_name_attr, val_ref)[0]
         except KeyError as e:
-            warn("The netCDF file does not contain the attribute {}".format(globals._ref_ds_attr))
+            warn("The netCDF file does not contain the attribute {}".format(
+                globals._ref_ds_attr))
             raise e
 
         return ref_dc
@@ -166,9 +175,7 @@ class QA4SMDatasets():
         """
         # try to get from self.meta
         try:
-            meta = self.meta[
-                globals.__dict__[template].format(dc)
-            ]
+            meta = self.meta[globals.__dict__[template].format(dc)]
         # try to get from globals
         except KeyError:
             # if there is an option to use
@@ -176,29 +183,24 @@ class QA4SMDatasets():
                 try:
                     backup_var = globals._backups[template]
                     # use the version short name (should be always in netCDF)
-                    meta = globals.__dict__[backup_var][
-                        self.meta[globals._version_short_name_attr.format(dc)]
-                    ]
+                    meta = globals.__dict__[backup_var][self.meta[
+                        globals._version_short_name_attr.format(dc)]]
                 # globals fallback has failed. Raise an exception
                 except KeyError or AttributeError:
                     raise Exception(
                         "Either the attribute {} is missing from the netCDF template, or the dictionaries"
-                        "in globals are not updated for the datasets used".format(
-                            globals._version_short_name_attr.format(dc)
-                        )
-                    )
+                        "in globals are not updated for the datasets used".
+                        format(globals._version_short_name_attr.format(dc)))
             # give warning and return an empty value
             else:
                 warnings.warn(
-                    "There is no attribute {} in the netCDF dataset. An empty string is returned".format(
-                        globals.__dict__[template].format(dc)
-                    )
-                )
+                    "There is no attribute {} in the netCDF dataset. An empty string is returned"
+                    .format(globals.__dict__[template].format(dc)))
                 meta = ""
 
         return meta
 
-    def _dc_names(self, dc:int) -> dict:
+    def _dc_names(self, dc: int) -> dict:
         """
         Get dataset meta values for the passed dc
 
@@ -213,19 +215,26 @@ class QA4SMDatasets():
             short name, pretty_name and short_version and pretty_version of the
             dc dataset.
         """
-        names = {'short_name': self._fetch_attribute("_ds_short_name_attr", dc),
-                 'pretty_name': self._fetch_attribute("_ds_pretty_name_attr", dc),
-                 'short_version': self._fetch_attribute("_version_short_name_attr", dc),
-                 'pretty_version': self._fetch_attribute("_version_pretty_name_attr", dc),
-                 'pretty_variable': self._fetch_attribute("_val_dc_variable_pretty_name", dc)}
+        names = {
+            'short_name':
+            self._fetch_attribute("_ds_short_name_attr", dc),
+            'pretty_name':
+            self._fetch_attribute("_ds_pretty_name_attr", dc),
+            'short_version':
+            self._fetch_attribute("_version_short_name_attr", dc),
+            'pretty_version':
+            self._fetch_attribute("_version_pretty_name_attr", dc),
+            'pretty_variable':
+            self._fetch_attribute("_val_dc_variable_pretty_name", dc)
+        }
 
         # not from dataset.
-        names['mu'] = "{}".format(
-                globals.get_metric_units(names['short_name'])
-            )
+        names['mu'] = "{}".format(globals.get_metric_units(
+            names['short_name']))
 
         # combined name for plots:
-        names['pretty_title'] = '{} ({})'.format(names['pretty_name'], names['pretty_version'])
+        names['pretty_title'] = '{} ({})'.format(names['pretty_name'],
+                                                 names['pretty_version'])
 
         return names
 
@@ -239,7 +248,7 @@ class QA4SMDatasets():
         """Id of the other datasets as in the variable names"""
         return [dc - self.offset for dc in self._dcs().keys()]
 
-    def _id2dc(self, id:int) -> int:
+    def _id2dc(self, id: int) -> int:
         """
         Offset ids according to the self.offset value
 
@@ -273,7 +282,7 @@ class QA4SMDatasets():
 
         return others_meta
 
-    def dataset_metadata(self, id:int, element:str or list=None) -> tuple:
+    def dataset_metadata(self, id: int, element: str or list = None) -> tuple:
         """
         Get the metadata for the dataset specified by the id. This function is used by the QA4SMMetricVariable class
 
@@ -295,7 +304,8 @@ class QA4SMDatasets():
 
         elif isinstance(element, str):
             if not element in names.keys():
-                raise ValueError("Elements must be one of '{}'".format(', '.join(names.keys())))
+                raise ValueError("Elements must be one of '{}'".format(
+                    ', '.join(names.keys())))
 
             meta = names[element]
 
@@ -370,6 +380,25 @@ class QA4SMVariable():
     def ismetric(self) -> bool:
         return self.g is not None
 
+    def _parse_wrap(self, pattern, g):
+        """Wrapper function that handles case of metric 'status' that occurs
+        in two globals.metric_groups (2,3). This is because a status array
+        can be the result of a validation between two or three datasets (tc)
+        """
+        # ignore this case - (status is also in globals.metric_groups 2 but
+        # should be treated as group 3)
+        if self.varname.startswith('status') and (self.varname.count('_and_')
+                                                  == 2) and g == 2:
+            return None
+        # parse self.varname when three datasets
+        elif self.varname.startswith('status') and (self.varname.count('_and_')
+                                                    == 2) and g == 3:
+            template = globals.var_name_ds_sep[3]
+            return parse(
+                '{}{}'.format(globals.var_name_metric_sep[2], template),
+                self.varname)
+        return parse(pattern, self.varname)
+
     def _parse_varname(self) -> (str, int, dict):
         """
         Parse the name to get the metric, group and variable data
@@ -391,15 +420,18 @@ class QA4SMVariable():
                 template = ''
             pattern = '{}{}'.format(globals.var_name_metric_sep[g], template)
             # parse infromation from pattern and name
-            parts = parse(pattern, self.varname)
 
-            if parts is not None and parts['metric'] in globals.metric_groups[g]:
+            parts = self._parse_wrap(pattern, g)
+
+            if parts is not None and parts['metric'] in globals.metric_groups[
+                    g]:
                 return parts['metric'], g, parts.named
             # perhaps it's a CI variable
             else:
                 pattern = '{}{}'.format(globals.var_name_CI[g], template)
                 parts = parse(pattern, self.varname)
-                if parts is not None and parts['metric'] in globals.metric_groups[g]:
+                if parts is not None and parts[
+                        'metric'] in globals.metric_groups[g]:
                     return parts['metric'], g, parts.named
 
         return None, None, None
@@ -436,7 +468,8 @@ class Metadata(QA4SMVariable):
     @property
     def key_meta(self) -> bool:
         """Filter out variables such as idx, lat, lon, gpi, time, _row_size etc."""
-        return self.varname in globals.metadata.keys()  # todo: retrieve without globals?
+        return self.varname in globals.metadata.keys(
+        )  # todo: retrieve without globals?
 
     @property
     def pretty_name(self) -> str:
@@ -449,6 +482,7 @@ class Metadata(QA4SMVariable):
 
 class QA4SMMetric():
     """Class for validation metric"""
+
     def __init__(self, name, variables_list=None):
 
         self.name = name
@@ -459,7 +493,7 @@ class QA4SMMetric():
             self.g = self._get_attribute('g')
             self.attrs = self._get_attribute('attrs')
 
-    def _get_attribute(self, attr:str):
+    def _get_attribute(self, attr: str):
         """
         Absorb Var attribute when is equal for all variables (e.g. group, reference dataset)
 
@@ -474,8 +508,10 @@ class QA4SMMetric():
         """
         for n, Var in enumerate(self.variables):
             value = getattr(Var, attr)
-            if n != 0:
-                assert value == previous, "The attribute {} is not equal in all variables".format(attr)
+            # special case for "status" attribute (self.g can be 2 or 3)
+            if n != 0 and not Var.varname.startswith('status'):
+                assert value == previous, "The attribute {} is not equal in all variables".format(
+                    attr)
             previous = value
 
         return value
@@ -489,4 +525,4 @@ class QA4SMMetric():
                 it_does = True
                 break
 
-        return  it_does
+        return it_does
