@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from qa4sm_reader import globals
 import qa4sm_reader.handlers as hdl
-from qa4sm_reader.plotting_methods import _format_floats, combine_soils, combine_depths
+from qa4sm_reader.plotting_methods import _format_floats, combine_soils, combine_depths, average_non_additive
 
 from pathlib import Path
 import warnings
@@ -29,7 +29,8 @@ class SpatialExtentError(Exception):
 
 class QA4SMImg(object):
     """A tool to analyze the results of a validation, which are stored in a netCDF file."""
-    def __init__(self, filepath,
+    def __init__(self,
+                 filepath,
                  period=None,
                  extent=None,
                  ignore_empty=True,
@@ -67,7 +68,8 @@ class QA4SMImg(object):
 
         self.ignore_empty = ignore_empty
         self.ds = self._open_ds(extent=extent, period=period, engine=engine)
-        self.extent = self._get_extent(extent=extent)  # get extent from .nc file if not specified
+        self.extent = self._get_extent(
+            extent=extent)  # get extent from .nc file if not specified
         self.datasets = hdl.QA4SMDatasets(self.ds.attrs)
 
         if load_data:
@@ -158,22 +160,26 @@ class QA4SMImg(object):
         if all(type in metadata.keys() for type in globals.soil_types):
             soil_dict = {type: metadata[type] for type in globals.soil_types}
             soil_combined = combine_soils(soil_dict)
-            metadata["soil_type"] = hdl.QA4SMVariable("soil_type", self.ds.attrs, values=soil_combined).initialize()
+            metadata["soil_type"] = hdl.QA4SMVariable(
+                "soil_type", self.ds.attrs, values=soil_combined).initialize()
 
         else:
-            warnings.warn(
-                "Not all: " + ", ".join(globals.soil_types) + " are present in the netCDF variables"
-            )
+            warnings.warn("Not all: " + ", ".join(globals.soil_types) +
+                          " are present in the netCDF variables")
 
         if all(type in metadata.keys() for type in globals.instrument_depths):
-            depth_dict = {type: metadata[type] for type in globals.instrument_depths}
+            depth_dict = {
+                type: metadata[type]
+                for type in globals.instrument_depths
+            }
             depth_combined = combine_depths(depth_dict)
-            metadata["instrument_depth"] = hdl.QA4SMVariable("instrument_depth", self.ds.attrs, values=depth_combined).initialize()
+            metadata["instrument_depth"] = hdl.QA4SMVariable(
+                "instrument_depth", self.ds.attrs,
+                values=depth_combined).initialize()
 
         else:
-            warnings.warn(
-                "Not all: " + ", ".join(globals.instrument_depths) + " are present in the netCDF variables"
-            )
+            warnings.warn("Not all: " + ", ".join(globals.instrument_depths) +
+                          " are present in the netCDF variables")
 
         return metadata
 
@@ -215,7 +221,8 @@ class QA4SMImg(object):
                 except KeyError:
                     values = None
 
-            Var = hdl.QA4SMVariable(varname, self.ds.attrs, values=values).initialize()
+            Var = hdl.QA4SMVariable(varname, self.ds.attrs,
+                                    values=values).initialize()
 
             if only_metrics and isinstance(Var, hdl.MetricVariable):
                 vars.append(Var)
@@ -247,7 +254,10 @@ class QA4SMImg(object):
 
         return Metrics
 
-    def _iter_vars(self, type:str=None, name:str=None, filter_parms:dict=None) -> iter:
+    def _iter_vars(self,
+                   type: str = None,
+                   name: str = None,
+                   filter_parms: dict = None) -> iter:
         """
         Iter through QA4SMVariable objects that are in the file
 
@@ -273,10 +283,11 @@ class QA4SMImg(object):
                 else:
                     continue
             if type and not isinstance(Var, type_lut[type]):
-                    continue
+                continue
             if filter_parms:
                 for key, val in filter_parms.items():
-                    if getattr(Var, key) == val:  # check all attribute individually
+                    if getattr(Var,
+                               key) == val:  # check all attribute individually
                         check = True
                     else:
                         check = False  # does not match requirements
@@ -300,7 +311,7 @@ class QA4SMImg(object):
                 if val is None or getattr(Metric, key) == val:
                     yield Metric
 
-    def group_vars(self, filter_parms:dict):
+    def group_vars(self, filter_parms: dict):
         """
         Return a list of QA4SMVariable that match filters
 
@@ -315,7 +326,7 @@ class QA4SMImg(object):
 
         return vars
 
-    def group_metrics(self, metrics:list=None) -> (dict, dict, dict):
+    def group_metrics(self, metrics: list = None) -> (dict, dict, dict):
         """
         Load and group all metrics from file
 
@@ -324,7 +335,7 @@ class QA4SMImg(object):
         metrics: list or None
             if list, only metrics in the list are grouped
         """
-        common, double, triple = {},{},{}
+        common, double, triple = {}, {}, {}
 
         # fetch Metrics
         if metrics is None:
@@ -342,7 +353,7 @@ class QA4SMImg(object):
 
         return common, double, triple
 
-    def _ds2df(self, varnames:list=None) -> pd.DataFrame:
+    def _ds2df(self, varnames: list = None) -> pd.DataFrame:
         """
         Return one or more or all variables in a single DataFrame.
 
@@ -360,13 +371,15 @@ class QA4SMImg(object):
             if varnames is None:
                 if globals.time_name in self.varnames:
                     if self.ds[globals.time_name].values.size == 0:
-                         self.ds = self.ds.drop_vars(globals.time_name)
+                        self.ds = self.ds.drop_vars(globals.time_name)
                 df = self.ds.to_dataframe()
             else:
                 df = self.ds[self.index_names + varnames].to_dataframe()
                 df.dropna(axis='index', subset=varnames, inplace=True)
         except KeyError as e:
-            raise Exception("The variable name '{}' does not match any name in the input values.".format(e.args[0]))
+            raise Exception(
+                "The variable name '{}' does not match any name in the input values."
+                .format(e.args[0]))
 
         if isinstance(df.index, pd.MultiIndex):
             lat, lon, gpi = globals.index_names
@@ -381,7 +394,7 @@ class QA4SMImg(object):
 
         return df
 
-    def metric_df(self, metrics:str or list):
+    def metric_df(self, metrics: str or list):
         """
         Group all variables for the metric in a common data frame
 
@@ -399,35 +412,33 @@ class QA4SMImg(object):
         if isinstance(metrics, list):
             Vars = []
             for metric in metrics:
-                Vars.extend(self.group_vars(filter_parms={'metric':metric}))
+                Vars.extend(self.group_vars(filter_parms={'metric': metric}))
         else:
-            Vars = self.group_vars(filter_parms={'metric':metrics})
+            Vars = self.group_vars(filter_parms={'metric': metrics})
 
         varnames = [Var.varname for Var in Vars]
         metrics_df = self._ds2df(varnames=varnames)
 
         return metrics_df
 
-    def get_cis(self, Var:hdl.MetricVariable) -> Union[list, None]:
+    def get_cis(self, Var: hdl.MetricVariable) -> Union[list, None]:
         """Return the CIs of a variable as a list of dfs ('upper' and 'lower'), if they exist in the netcdf"""
         cis = []
         if not self.has_CIs:
             return cis
-        for ci in self._iter_vars(
-                type="ci",
-                filter_parms={
-                    "metric":Var.metric,
-                    "metric_ds":Var.metric_ds,
-                    "other_ds":Var.other_ds,
-                }
-        ):
+        for ci in self._iter_vars(type="ci",
+                                  filter_parms={
+                                      "metric": Var.metric,
+                                      "metric_ds": Var.metric_ds,
+                                      "other_ds": Var.other_ds,
+                                  }):
             values = ci.values
             values.columns = [ci.bound]
             cis.append(values)
 
         return cis
 
-    def _metric_stats(self, metric, id=None)  -> list:
+    def _metric_stats(self, metric, id=None) -> list:
         """
         Provide a list with the metric summary statistics for each variable or for all variables
         where the dataset with id=id is the metric dataset.
@@ -445,20 +456,33 @@ class QA4SMImg(object):
             List of (variable) lists with summary statistics
         """
         metric_stats = []
-        filters = {'metric':metric}
+        filters = {'metric': metric}
         if id:
             filters.update(id=id)
+
+        # The number of observations are needed for the averaging of correlation values
+        for Var in self._iter_vars(type="metric",
+                                   filter_parms={'metric': 'n_obs'}):
+            nobs = Var.values[Var.varname]
+
         # get stats by metric
         for Var in self._iter_vars(type="metric", filter_parms=filters):
-            # get interquartile range 
+            # get interquartile range
             values = Var.values[Var.varname]
             # take out variables with all NaN or NaNf
             if values.isnull().values.all():
                 continue
-            iqr = values.quantile(q=[0.75,0.25]).diff()
+            iqr = values.quantile(q=[0.75, 0.25]).diff()
             iqr = abs(float(iqr.loc[0.25]))
+
+            # Mean of correlation values has to be computed differently
+            if metric in ["R", "rho"]:
+                mean = average_non_additive(values, nobs)
+            else:
+                mean = values.mean()
+
             # find the statistics for the metric variable
-            var_stats = [i for i in (values.mean(), values.median(), iqr)]
+            var_stats = [mean, values.median(), iqr]
             if Var.g == 0:
                 var_stats.append('All datasets')
                 var_stats.extend([globals._metric_name[metric], Var.g])
@@ -466,23 +490,27 @@ class QA4SMImg(object):
             else:
                 i, ds_name = Var.metric_ds
                 if Var.g == 2:
-                    var_stats.append('{}-{} ({})'.format(i, ds_name['short_name'], ds_name['pretty_version']))
+                    var_stats.append('{}-{} ({})'.format(
+                        i, ds_name['short_name'], ds_name['pretty_version']))
 
                 elif Var.g == 3:
                     o, other_ds = Var.other_ds
-                    var_stats.append('{}-{} ({}); other ref: {}-{} ({})'.format(i, ds_name['short_name'],
-                                                                                ds_name['pretty_version'],
-                                                                                o, other_ds['short_name'],
-                                                                                other_ds['pretty_version']))
-
-                metric_def = f"{globals._metric_name[metric]} [{globals.get_metric_units(ds_name['short_name'])}]"
+                    var_stats.append(
+                        '{}-{} ({}); other ref: {}-{} ({})'.format(
+                            i, ds_name['short_name'],
+                            ds_name['pretty_version'], o,
+                            other_ds['short_name'],
+                            other_ds['pretty_version']))
+                um = globals._metric_description[metric].format(
+                    globals.get_metric_units(self.datasets.ref['short_name']))
+                metric_def = f"{globals._metric_name[metric]} {um}"
 
                 var_stats.extend([metric_def, Var.g])
             # put the separate variable statistics in the same list
             metric_stats.append(var_stats)
 
         return metric_stats
-    
+
     def stats_df(self) -> pd.DataFrame:
         """
         Create a DataFrame with summary statistics for all the metrics
@@ -495,14 +523,19 @@ class QA4SMImg(object):
         stats = []
         # find stats for all the metrics
         for metric in self.metrics.keys():
+
+            # Pointless to compute the summary statistics for the
+            # significance scores
+            if metric in ["p_R", "p_rho"]:
+                continue
+
             stats.extend(self._metric_stats(metric))
         # create a dataframe
-        stats_df = pd.DataFrame(
-            stats,
-            columns=[
-                'Mean', 'Median', 'IQ range', 'Dataset', 'Metric', 'Group'
-            ]
-        )
+        stats_df = pd.DataFrame(stats,
+                                columns=[
+                                    'Mean', 'Median', 'IQ range', 'Dataset',
+                                    'Metric', 'Group'
+                                ])
         stats_df.set_index('Metric', inplace=True)
         stats_df.sort_values(by='Group', inplace=True)
         # format the numbers for display
@@ -510,4 +543,3 @@ class QA4SMImg(object):
         stats_df.drop(labels='Group', axis='columns', inplace=True)
 
         return stats_df
-
